@@ -456,6 +456,10 @@ class SQLEnumerable:
         """
         Add an INSERT command to the command list.
 
+        If data is a list, that means you make a multi insert.
+        For more see: `docs/doc/examples/examples.md`
+            or Usage.insert in the documentation.
+
         Args:
             column: Column where we want to insert.
             data: Data we want to insert.
